.. Django Grappelli documentation master file, created by
   sphinx-quickstart on Sun Dec  5 19:11:46 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser
.. |grappelliversion| replace:: 2.4.8

.. _index:

Documentation
=============

**A jazzy skin for the Django admin interface**.

This documentation covers version |version| of |grappelli|. |grappelli| is a grid-based alternative/extension to the `Django <http://www.djangoproject.com>`_ administration interface.

.. note::
    |grappelli| |version| requires Django 1.4/1.5. More on :ref:`versions`.

Installation & Setup
--------------------

.. toctree::
   :maxdepth: 2
   
   quickstart
   customization

Dashboard
---------

.. toctree::
   :maxdepth: 2
   
   dashboard_setup
   dashboard_api

Internals
---------

.. toctree::
   :maxdepth: 2
   
   templates
   javascripts

Help
----

.. toctree::
   :maxdepth: 1
   
   faq
   bestpractice
   thirdparty
   troubleshooting
   djangoissues
   releasenotes
   changelog

Code
----

https://github.com/sehmaschine/django-grappelli

Website
-------

http://www.grappelliproject.com

Discussion
----------

Use the `Grappelli Google Group <http://groups.google.com/group/django-grappelli>`_ to ask questions or discuss features.

.. _versions:

Versions and Compatibility
--------------------------

**Grappelli is always developed against the latest stable Django release and is NOT tested with Djangos trunk.**

* |grappelli| 2.5.0 (November 13th, 2013): Compatible with Django 1.6
* |grappelli| 2.4.8 (November 12th, 2013): Compatible with Django 1.4/1.5

Current development branches:

* |grappelli| 2.5.1 (Development version for Django 1.6, see branch Stable/2.5.x)
* |grappelli| 2.4.9 (Development version for Django 1.4/1.5, see branch Stable/2.4.x)

Older versions are availabe at GitHub, but are not supported anymore.